@@ -4,13 +4,13 @@
     'name': 'Account Belgium',
     'name_de_DE': 'Buchhaltung Belgien',
     'name_fr_FR': 'Comptabilité belge',
-    'version': '2.0.0',
+    'version': '2.2.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
     'description': '''Define an account chart template for Belgium.
 Usefull to create a Belgium account chart with the wizard in
-"Financial Management>Configuration>General Account>Create Chart of Account from Template".
+"Financial>Configuration>General Account>Create Chart of Account from Template".
 ''',
     'description_de_DE': '''
     - Enthält den Kontenplan für Belgien.
